@@ -47,12 +47,18 @@
 #' @seealso  \code{\link{gray_scale}}
 #' @importFrom graphics par
 #' @importFrom parallel clusterExport stopCluster parLapply
+#' @return Apresenta uma imagem para selecao do indice mais apropriado para a segmentacao
+#' (It presents an image for selection of the most appropriate index for segmentation).
 
 #' @examples
-#' \donttest{
+#' \dontrun{
+#' # Not run: Depende da interacao com uma interface grafica
+#' #(It depends on interaction with a graphical interface).
+#'
+#'
 #'#Carregar imagem de exemplo
 #'im=read_image(example_image(2),plot=TRUE)
-#'plot_indexes(im,NumberCores=2)
+#'plot_indexes(im)
 #'}
 
 #'@export
@@ -93,15 +99,17 @@ r <- parallel::parLapply(cl = cl,1:25, function(x){gray_scale(im,method =method[
 n=length(indexes)
 linha=ceiling(sqrt(n))
 coluna=ceiling(n/linha)
-
+oldpar <- par(no.readonly = TRUE) # code line
 op <- par(mfrow = c(linha,coluna))
 #on.exit(par(op))
 for(i in 1:n){
   plot_image((r[i][[1]]))
   text(lin/2,col/2,method[i],col="red",cex=2)
   #print(method[i])
+  on.exit(par(oldpar))
 }
-par(mfrow = c(1,1))
+#par(mfrow = c(1,1))
+
 #dev.off()
 }
 
